"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../index");
/**
 * VUE Generator 扩展
 * @param api GeneratorAPI 实例
 * @param opts 插件配置选项
 * @param preset 当前使用预设
 */
exports.default = (api, opts, preset) => {
    const isVue3 = preset.vueVersion === '3';
    /* 预设中的配置 */
    const { antd } = preset;
    const mergeOpts = { ...index_1.DEFAULT_ANTD_PLUGIN_OPTION, ...opts };
    if (!mergeOpts.registry) {
        delete mergeOpts.registry;
    }
    const { version, ...rest } = mergeOpts;
    const devDependencies = {
        less: version.less,
        'less-loader': version['less-loader'],
    };
    const babel = { plugins: [] };
    if (opts.importType === 'full') {
        /* 全量导入时自动引入组件及样式 */
        const suffix = opts.style === true ? 'less' : 'css';
        api.injectImports(api.entryFile, [
            `import Antd from 'ant-design-vue'`,
            `import 'ant-design-vue/dist/antd.${suffix}'`,
        ]);
        const codeMod = require('./useAntd');
        api.transformScript(api.entryFile, codeMod);
    }
    else {
        /* 非全量时添加按需加载插件 */
        babel.plugins.push(['import', { libraryName: 'ant-design-vue', libraryDirectory: 'es', style: opts.style }]);
        devDependencies['babel-plugin-import'] = version['babel-plugin-import'];
    }
    if (babel.plugins.length === 0) {
        delete babel.plugins;
    }
    api.extendPackage({
        dependencies: {
            'ant-design-vue': version['ant-design-vue'],
        },
        devDependencies,
        babel,
        vue: {
            pluginOptions: {
                antd: { ...rest },
            },
            css: {
                loaderOptions: {
                    less: { lessOptions: { javascriptEnabled: true } },
                },
            },
        },
    });
    /* 渲染模板 */
    // api.render('./template');
    // api.postProcessFiles((files) => {});
};
